==> account_kit-3.0.5.tar.gz: lib/redux/user/userActions.dart <==
import 'package:account_kit/constants.dart';
import 'package:account_kit/entities/request/request.dart' as UserRequest;
import 'package:account_kit/entities/user/user.dart';
import 'package:built_collection/built_collection.dart';
import 'package:http/http.dart';
import 'package:puma_core/redux/core/coreAction.dart';
import 'package:puma_network/redux/api/apiAction.dart';
import 'package:puma_network/redux/network/networkAction.dart';
import 'package:puma_network/redux/network/networkState.dart';
import 'package:redux/redux.dart';

class PostSignin extends PostAction with Anonymous implements CallbackAction {
  static const String _PATH = "/account/users/signin";
  final String email;
  final String password;
  final Function()? callback;
  final bool permanent;
  final String dispatcherKey = constDispatcherKey;

  PostSignin(this.email, this.password, {this.callback, this.permanent = true})
      : super("$_PATH",
            {"email": email, "password": password, "permanent": permanent});

  decodeResponse(Store store, Response data) {
    var user = User.fromJson(data.body);
    store.dispatch(AccountLoadedAction(user!));
    store.dispatch(SetTokenNetworkAction(user.token!));
  }
}

class PostPLSignin extends PostAction with Anonymous implements CallbackAction {
  static const String _PATH = "/account/users/plSignin";
  final String code;
  final Function()? callback;
  final String dispatcherKey = constDispatcherKey;

  PostPLSignin(this.code, {this.callback}) : super("$_PATH", {"code": code});

  decodeResponse(Store store, Response data) {
    var user = User.fromJson(data.body);
    store.dispatch(AccountLoadedAction(user!));
    store.dispatch(SetTokenNetworkAction(user.token!));
  }
}

class PostRequestPLCode extends PostAction
    with Anonymous
    implements CallbackAction {
  static const String _PATH = "/account/users/requestPLCode";
  final String email;
  final Function()? callback;
  final String dispatcherKey = constDispatcherKey;

  PostRequestPLCode(this.email, {this.callback})
      : super("$_PATH", {"email": email});

  decodeResponse(Store store, Response data) {
    var request = UserRequest.Request.fromJson(data.body);
    store.dispatch(UserRequestLoadedAction(request!));
    // store.dispatch(SetTokenNetworkAction(user.token));
  }
}

class PostPLSignup extends PostAction with Anonymous {
  static const String _PATH = "/account/users/plSignup";
  final String firstName;
  final String lastName;
  final String email;
  final String? organizationToken;
  final String dispatcherKey = constDispatcherKey;

  PostPLSignup({
    required this.firstName,
    required this.lastName,
    required this.email,
    this.organizationToken,
  }) : super("$_PATH", {
          "firstName": firstName,
          "lastName": lastName,
          "email": email,
          "organizationToken": organizationToken,
        });
  decodeResponse(Store store, Response data) {
    var request = UserRequest.Request.fromJson(data.body);
    store.dispatch(UserRequestLoadedAction(request!));
  }
}

class PostSignup extends PostAction with Anonymous {
  static const String _PATH = "/account/users/signup";
  final String firstName;
  final String lastName;
  final String email;
  final String password;
  final String passwordConfirmation;
  final String? organizationToken;

  final String dispatcherKey = constDispatcherKey;

  PostSignup({
    required this.firstName,
    required this.lastName,
    required this.email,
    required this.password,
    required this.passwordConfirmation,
    this.organizationToken,
  }) : super("$_PATH", {
          "firstName": firstName,
          "lastName": lastName,
          "email": email,
          "password": password,
          "passwordConfirmation": passwordConfirmation,
          "organizationToken": organizationToken,
        });
  decodeResponse(Store store, Response data) {
    var user = User.fromJson(data.body);
    store.dispatch(AccountLoadedAction(user!));
  }
}

class SignupSuccessAction extends CoreAction {
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  SignupSuccessAction()
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class GetUserAction extends GetAction {
  static const String _PATH = "/account/users/current";
  final String dispatcherKey = constDispatcherKey;

  GetUserAction() : super("$_PATH");

  decodeResponse(Store store, Response data) {
    var user = User.fromJson(data.body);
    store.dispatch(AccountLoadedAction(user!));
  }
}

class GetUsersAction extends GetAction {
  static const String _PATH = "/account/users";
  final String dispatcherKey = constDispatcherKey;

  GetUsersAction() : super(_PATH);

  decodeResponse(Store store, Response data) {
    BuiltList<User> contacts = User.listFromJson(data.body);
    store.dispatch(GetUsersSuccessAction(contacts));
  }
}

class GetUsersSuccessAction extends CoreAction {
  final BuiltList<User> users;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;
  GetUsersSuccessAction(this.users)
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class AccountLoadedAction extends CoreAction {
  final User user;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  AccountLoadedAction(this.user)
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class GetUserOpaReadyAction extends GetAction {
  static const String _PATH = "/account/users/opaReady";
  final String dispatcherKey = constDispatcherKey;

  GetUserOpaReadyAction() : super("$_PATH");

  decodeResponse(Store store, Response data) {
    store.dispatch(GetUserOpaReadySuccessAction());
  }
}

class GetUserOpaReadySuccessAction extends CoreAction {
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  GetUserOpaReadySuccessAction()
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class UserRequestLoadedAction extends CoreAction {
  final UserRequest.Request request;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  UserRequestLoadedAction(this.request)
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class SigninLoadedAction extends CoreAction {
  final User user;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;
  SigninLoadedAction(this.user)
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class SignOutAction extends DeleteAction {
  static const String _PATH = "/account/sessions/current";
  final String token;
  final String dispatcherKey = constDispatcherKey;
  Map<String, String> headers(NetworkState _) => {"auth-server-token": token};

  SignOutAction(this.token) : super("$_PATH");
}

class SigninWithBiometricAccessToken extends CoreAction {
  final String token;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;
  SigninWithBiometricAccessToken(this.token)
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class ClearUserRequestAction extends CoreAction {
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  ClearUserRequestAction()
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

// Update Current User
class UpdateCurrentUserAction extends PutAction {
  static const String _PATH = "/account/users/current";
  final Map<dynamic, dynamic> body;

  final String dispatcherKey = constDispatcherKey;
  UpdateCurrentUserAction(this.body)
      : super(
          "$_PATH",
          body,
        );

  decodeResponse(Store store, Response data) {
    store.dispatch(UpdateCurrentUserSuccessAction(body));
  }
}

class UpdateCurrentUserSuccessAction {
  final Map<dynamic, dynamic> body;
  final String dispatcherKey = constDispatcherKey;

  UpdateCurrentUserSuccessAction(this.body);
}

// Validate Code
class VerificationCodeAction extends PostAction {
  static const String _PATH = "/account/verificationCodes/validate";
  final Map<dynamic, dynamic> body;
  final String dispatcherKey = constDispatcherKey;

  VerificationCodeAction(body)
      : body = body,
        super("$_PATH", body);

  decodeResponse(Store store, Response data) {
    store.dispatch(VerificationCodeSuccessAction(body));
  }
}

class ImpersonateAction extends PostAction {
  static const String _PATH = "/account/users";
  final String dispatcherKey = constDispatcherKey;
  final String uuid;
  final Map<dynamic, dynamic> body;

  ImpersonateAction(this.body, this.uuid)
      : super("$_PATH/$uuid/impersonate", body);

  decodeResponse(Store store, Response data) {
    print(data.headers);
    print("auth-impersonate-token: ${data.headers["auth-impersonate-token"]}");
    print(data.body);
    store.dispatch(ImpersonateSuccessAction(
        user: User.fromJson(data.body)!,
        authImpersonateToken: data.headers["auth-impersonate-token"]!));
  }
}

class ImpersonateSuccessAction extends CoreAction {
  User user;
  String authImpersonateToken;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  ImpersonateSuccessAction(
      {required this.user, required this.authImpersonateToken})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class StopImpersonateAction extends DeleteAction {
  static const String _PATH = "/account/users/current/stopImpersonate";
  final String token;
  final String dispatcherKey = constDispatcherKey;
  Map<String, String> headers(NetworkState _) =>
      {"auth-impersonate-token": token};

  StopImpersonateAction(this.token) : super("$_PATH");
}

class VerificationCodeSuccessAction {
  final Map<dynamic, dynamic> body;
  final String dispatcherKey = constDispatcherKey;

  VerificationCodeSuccessAction(this.body);
}

class SetCheckingOpa {
  final bool value;
  final String dispatcherKey = constDispatcherKey;

  SetCheckingOpa(this.value);
}

class SetOpaReady {
  final bool value;
  final String dispatcherKey = constDispatcherKey;

  SetOpaReady(this.value);
}

==> account_kit-3.0.8.tar.gz: lib/redux/user/userActions.dart <==
import 'package:account_kit/constants.dart';
import 'package:account_kit/entities/request/request.dart' as UserRequest;
import 'package:account_kit/entities/session/session.dart';
import 'package:account_kit/entities/sessionRequest/sessionRequest.dart';
import 'package:account_kit/entities/user/user.dart';
import 'package:built_collection/built_collection.dart';
import 'package:http/http.dart';
import 'package:puma_core/redux/core/coreAction.dart';
import 'package:puma_network/redux/api/apiAction.dart';
import 'package:puma_network/redux/network/networkAction.dart';
import 'package:puma_network/redux/network/networkState.dart';
import 'package:redux/redux.dart';

class PostSignin extends PostAction with Anonymous implements CallbackAction {
  static const String _PATH = "/account/users/signin";
  final String email;
  final String password;
  final Function()? callback;
  final bool permanent;
  final String dispatcherKey = constDispatcherKey;

  PostSignin(this.email, this.password, {this.callback, this.permanent = true})
      : super("$_PATH",
            {"email": email, "password": password, "permanent": permanent});

  decodeResponse(Store store, Response data) {
    var user = User.fromJson(data.body);
    store.dispatch(AccountLoadedAction(user!));
    store.dispatch(SetTokenNetworkAction(user.token!));
  }
}

class PostPLSignin extends PostAction with Anonymous implements CallbackAction {
  static const String _PATH = "/account/users/signinPL";
  final String code;
  final Function()? callback;
  final String dispatcherKey = constDispatcherKey;

  PostPLSignin(this.code, {this.callback}) : super("$_PATH", {"code": code});

  decodeResponse(Store store, Response data) {
    var user = User.fromJson(data.body);
    store.dispatch(AccountLoadedAction(user!));
    store.dispatch(SetTokenNetworkAction(user.token ?? ""));
  }
}

class PostRequestPLCode extends PostAction
    with Anonymous
    implements CallbackAction {
  static const String _PATH = "/account/users/requestPLCode";
  final String email;
  final String phone;
  final Function()? callback;
  final String dispatcherKey = constDispatcherKey;

  PostRequestPLCode(this.email, this.phone, {this.callback})
      : super(
          "$_PATH",
          {
            "email": email,
            "phone": phone,
          },
        );

  decodeResponse(Store store, Response data) {
    var request = SessionRequest.fromJson(data.body);
    // var request = UserRequest.Request.fromJson(data.body);
    store.dispatch(SessionRequestLoadedAction(request!));
  }
}

class PostPLSignup extends PostAction with Anonymous {
  static const String _PATH = "/account/users/plSignup";
  final String firstName;
  final String lastName;
  final String email;
  final String phone;
  final String? organizationToken;
  final String dispatcherKey = constDispatcherKey;

  PostPLSignup({
    required this.firstName,
    required this.lastName,
    required this.email,
    required this.phone,
    this.organizationToken,
  }) : super("$_PATH", {
          "firstName": firstName,
          "lastName": lastName,
          "email": email,
          "phone": phone,
          "organizationToken": organizationToken,
        });
  decodeResponse(Store store, Response data) {
    var request = UserRequest.Request.fromJson(data.body);
    store.dispatch(UserRequestLoadedAction(request!));
  }
}

class PostSignup extends PostAction with Anonymous {
  static const String _PATH = "/account/users/signup";
  final String firstName;
  final String lastName;
  final String email;
  final String password;
  final String passwordConfirmation;
  final String? organizationToken;

  final String dispatcherKey = constDispatcherKey;

  PostSignup({
    required this.firstName,
    required this.lastName,
    required this.email,
    required this.password,
    required this.passwordConfirmation,
    this.organizationToken,
  }) : super("$_PATH", {
          "firstName": firstName,
          "lastName": lastName,
          "email": email,
          "password": password,
          "passwordConfirmation": passwordConfirmation,
          "organizationToken": organizationToken,
        });
  decodeResponse(Store store, Response data) {
    var user = User.fromJson(data.body);
    store.dispatch(AccountLoadedAction(user!));
  }
}

class SignupSuccessAction extends CoreAction {
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  SignupSuccessAction()
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class GetUserAction extends GetAction {
  static const String _PATH = "/account/users/current";
  final String dispatcherKey = constDispatcherKey;

  GetUserAction() : super("$_PATH");

  decodeResponse(Store store, Response data) {
    var user = User.fromJson(data.body);
    store.dispatch(AccountLoadedAction(user!));
  }
}

class GetUsersAction extends GetAction {
  static const String _PATH = "/account/users";
  final String dispatcherKey = constDispatcherKey;
  final Map<String, String> queryParams;

  GetUsersAction(Map<String, String> queryParams)
      : this.queryParams = queryParams,
        super(_PATH);

  decodeResponse(Store store, Response data) {
    BuiltList<User> contacts = User.listFromJson(data.body);
    store.dispatch(GetUsersSuccessAction(contacts));
  }
}

class GetUsersSuccessAction extends CoreAction {
  final BuiltList<User> users;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;
  GetUsersSuccessAction(this.users)
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class AccountLoadedAction extends CoreAction {
  final User user;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  AccountLoadedAction(this.user)
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class GetUserOpaReadyAction extends GetAction {
  static const String _PATH = "/account/users/opaReady";
  final String dispatcherKey = constDispatcherKey;

  GetUserOpaReadyAction() : super("$_PATH");

  decodeResponse(Store store, Response data) {
    store.dispatch(GetUserOpaReadySuccessAction());
  }
}

class GetUserOpaReadySuccessAction extends CoreAction {
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  GetUserOpaReadySuccessAction()
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class SessionRequestLoadedAction extends CoreAction {
  final SessionRequest request;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  SessionRequestLoadedAction(this.request)
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class UserRequestLoadedAction extends CoreAction {
  final UserRequest.Request request;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  UserRequestLoadedAction(this.request)
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class SigninLoadedAction extends CoreAction {
  final User user;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;
  SigninLoadedAction(this.user)
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class SignOutAction extends DeleteAction {
  static const String _PATH = "/account/sessions/current";
  final String token;
  final String dispatcherKey = constDispatcherKey;
  Map<String, String> headers(NetworkState _) => {"auth-server-token": token};

  SignOutAction(this.token) : super("$_PATH");
}

class SigninWithBiometricAccessToken extends CoreAction {
  final String token;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;
  SigninWithBiometricAccessToken(this.token)
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class ClearUserRequestAction extends CoreAction {
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  ClearUserRequestAction()
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class ClearSessionRequestAction extends CoreAction {
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  ClearSessionRequestAction()
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

// Update Current User
class UpdateCurrentUserAction extends PutAction {
  static const String _PATH = "/account/users/current";
  final Map<dynamic, dynamic> body;

  final String dispatcherKey = constDispatcherKey;
  UpdateCurrentUserAction(this.body)
      : super(
          "$_PATH",
          body,
        );

  decodeResponse(Store store, Response data) {
    store.dispatch(UpdateCurrentUserSuccessAction(body));
  }
}

class UpdateCurrentUserSuccessAction {
  final Map<dynamic, dynamic> body;
  final String dispatcherKey = constDispatcherKey;

  UpdateCurrentUserSuccessAction(this.body);
}

// Validate Code
class VerificationCodeAction extends PostAction {
  static const String _PATH = "/account/verificationCodes/validate";
  final Map<dynamic, dynamic> body;
  final String dispatcherKey = constDispatcherKey;

  VerificationCodeAction(body)
      : body = body,
        super("$_PATH", body);

  decodeResponse(Store store, Response data) {
    store.dispatch(VerificationCodeSuccessAction(body));
  }
}

class ImpersonateAction extends PostAction {
  static const String _PATH = "/account/users";
  final String dispatcherKey = constDispatcherKey;
  final String uuid;
  final Map<dynamic, dynamic> body;

  ImpersonateAction(this.body, this.uuid)
      : super("$_PATH/$uuid/impersonate", body);

  decodeResponse(Store store, Response data) {
    print(data.body);
    store.dispatch(
      ImpersonateSuccessAction(
        session: Session.fromJson(data.body)!,
      ),
    );
  }
}

class ImpersonateSuccessAction extends CoreAction {
  // User user;
  Session session;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  ImpersonateSuccessAction({required this.session})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class StopImpersonateAction extends DeleteAction {
  static const String _PATH = "/account/users/current/stopImpersonate";
  final String dispatcherKey = constDispatcherKey;

  StopImpersonateAction() : super("$_PATH");
}

class VerificationCodeSuccessAction {
  final Map<dynamic, dynamic> body;
  final String dispatcherKey = constDispatcherKey;

  VerificationCodeSuccessAction(this.body);
}

class SetCheckingOpa {
  final bool value;
  final String dispatcherKey = constDispatcherKey;

  SetCheckingOpa(this.value);
}

class SetOpaReady {
  final bool value;
  final String dispatcherKey = constDispatcherKey;

  SetOpaReady(this.value);
}
